/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.shared;

import java.util.concurrent.locks.ReentrantLock;

/**
 * A multiple-reader plus single-writer lock. This lock permits readers to obtain their locks under any condition, but
 * allows only one writer at a time. Writers can acquire a read lock, and readers can acquire the write lock.
 *
 */
public class LockMRPlusSW extends ReentrantLock implements Lock {

	@Override
	public void enterCriticalSection(final boolean readLockRequested) {
		if (!readLockRequested) lock();
	}

	@Override
	public void leaveCriticalSection() {
		if (isHeldByCurrentThread()) unlock();
	}
}
